==> dl.php?src=linea21_1_6.zip: linea21/languages/en/lang_search.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "search";


$lang['search']['result'] = "Search results";
$lang['search']['keywords'] = "Keyword(s) : ";
$lang['search']['method'] = "Method : ";
$lang['search']['min_length']='3 characters at least are required';
$lang['search']['query_time']='Query time executed in';
$lang['search']['query_seconds']='seconds';
$lang['search']['no_result'] = "no result";
$lang['search']['score'] = "relevancy score";
$lang['search']['score_abbr'] = "rs";
$lang['search']['score_not_good'] = "not relevant";

$lang['search']['one_of_them'] = "one of these words";
$lang['search']['all_of_them'] = "all these words";
$lang['search']['expression'] = "full expression";
$lang['search']['text_button'] = "Search";

$lang['search']['comment_module'] = "In comments";
$lang['search']['project_module'] = "In projets";
$lang['search']['news_module'] = "In news";
$lang['search']['page_module'] = "In pages";
$lang['search']['newsletter_module'] = "In newsletters";
$lang['search']['publication_module'] = "In publications";
$lang['search']['det_publication_module'] = "In publications parts";
$lang['search']['workshop_module'] = "In workgroups";
$lang['search']['workshoprep_module'] = "In workgroups reports";
$lang['search']['workshoprepcon_module'] = "In workgroups reports parts";
$lang['search']['workshopcal_module'] = "In workgroups calendars";
$lang['search']['workshopcom_module'] = "In workgroups chats";
$lang['search']['sdi_module'] = 'In Sustainable Development Indicators';
$lang['search']['yellowpages_module'] = "In directory";
$lang['search']['user_module'] = "In users repository";
$lang['search']['theme_module'] = "In themes";
$lang['search']['scale_module'] = "In scales";
$lang['search']['level_module'] = "In levels";

$lang['search']['help']="Search engine ".SITE_LINEA_NAME;
$lang['search']['help_list1']="To make a global search, click on \"Search\" or directly type a keyword in the text box under the left menu";
$lang['search']['help_list2']="To make a search on a specific module, go to module and click on the 'Search' link";
$lang['search']['help_list3']="The relevance indice is relative todocuments found by the search engine: the most relevant document has the highest indice.";

?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/en/lang_search.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['search']['section'] = "search";


$lang['search']['result'] = "Search results";
$lang['search']['keywords'] = "Keyword(s) : ";
$lang['search']['method'] = "Method : ";
$lang['search']['min_length']='At least 3 characters are required';
$lang['search']['query_time']='Query time executed in';
$lang['search']['query_seconds']='seconds';
$lang['search']['no_result'] = "no result";
$lang['search']['score'] = "relevancy score";
$lang['search']['score_abbr'] = "rs";
$lang['search']['score_not_good'] = "not relevant";

$lang['search']['one_of_them'] = "one of these words";
$lang['search']['all_of_them'] = "all these words";
$lang['search']['expression'] = "full expression";
$lang['search']['text_button'] = "Search";

$lang['search']['comment_module'] = "In comments";
$lang['search']['project_module'] = "In projets";
$lang['search']['news_module'] = "In news";
$lang['search']['page_module'] = "In pages";
$lang['search']['newsletter_module'] = "In newsletters";
$lang['search']['publication_module'] = "In publications";
$lang['search']['det_publication_module'] = "In publications parts";
$lang['search']['workshop_module'] = "In workgroups";
$lang['search']['workshoprep_module'] = "In workgroups reports";
$lang['search']['workshoprepcon_module'] = "In workgroups reports parts";
$lang['search']['workshopcal_module'] = "In workgroups calendars";
$lang['search']['workshopcom_module'] = "In workgroups chats";
$lang['search']['sdi_module'] = 'In Sustainable Development Indicators';
$lang['search']['yellowpages_module'] = "In directory";
$lang['search']['user_module'] = "In users repository";
$lang['search']['theme_module'] = "In themes";
$lang['search']['scale_module'] = "In scales";
$lang['search']['level_module'] = "In levels";

$lang['search']['help']="Search engine ".SITE_LINEA_NAME;
$lang['search']['help_list1']="To make a global search, click on \"Search\" or directly type a keyword in the text box under the left menu";
$lang['search']['help_list2']="To make a search on a specific module, go to module and click on the 'Search' link";
$lang['search']['help_list3']="The relevance indice is relative todocuments found by the search engine: the most relevant document has the highest indice.";

?>
